@@ -45,7 +45,7 @@ def test_open_file():
 def test_doc_tag():
     # test that strings, BS doc and BS tags are all parsed
     doc = '''<article class="h-entry"></article>'''
-    soup = BeautifulSoup(doc)
+    soup = BeautifulSoup(doc, 'html5lib')
     parse_string = Parser(doc).to_dict()
     assert 'h-entry' in parse_string['items'][0]['type']
     parse_doc = Parser(soup).to_dict()
@@ -160,6 +160,7 @@ def test_datetime_parsing():
 
 def test_datetime_vcp_parsing():
     result = parse_fixture("datetimes.html")
+    assert_equal(len(result['items']), 16)
     assert_equal(result["items"][1]["properties"]["published"][0],
                  "3014-01-01 01:21Z")
     assert_equal(result["items"][2]["properties"]["updated"][0],
@@ -184,7 +185,14 @@ def test_datetime_vcp_parsing():
                  "2014-06-01 12:15")
     assert_equal(result["items"][11]["properties"]["start"][0],
                  "2016-03-02 00:30-06:00")
-
+    assert_equal(result["items"][12]["properties"]["start"][0],
+                 "2014-06-01 12:30-6:00")
+    assert_equal(result["items"][13]["properties"]["start"][0],
+                 "2014-06-01 12:30+6:00")
+    assert_equal(result["items"][14]["properties"]["start"][0],
+                 "2014-06-01 12:30Z")
+    assert_equal(result["items"][15]["properties"]["start"][0],
+                 "2014-06-01 12:30-6:00")
 def test_dt_end_implied_date():
     """Test that events with dt-start and dt-end use the implied date rule
     http://microformats.org/wiki/value-class-pattern#microformats2_parsers
@@ -621,7 +629,7 @@ def test_backcompat_hproduct():
     assert_equal(['bullshit'], result["items"][0]["properties"]["category"])
     assert_equal(['Quacktastic Products'], result["items"][0]["properties"]["brand"])
     assert_equal(['#BULLSHIT-001'], result["items"][0]["properties"]["identifier"])
-    assert_equal("Magical tasty sugar pills that don't do anything.", result["items"][0]["properties"]['description'][0]) 
+    assert_equal("Magical tasty sugar pills that don't do anything.", result["items"][0]["properties"]['description'][0])
     assert_equal(["Tom's Magical Quack Tincture"], result["items"][0]["properties"]["name"])
 
 
@@ -851,6 +859,14 @@ def test_photo_with_alt():
     assert_equal('', exp_result['items'][5]['properties']['in-reply-to'][0]['properties']['photo'][0]['alt'])
     assert_equal('', exp_result['items'][5]['properties']['in-reply-to'][0]['alt'])
 
+
+def test_parse_id():
+    result = parse_fixture("parse_id.html")
+    assert_equal("recentArticles", result['items'][0]['id'])
+    assert_equal("article", result['items'][0]['children'][0]['id'])
+    assert_true("id" not in result['items'][0]['children'][1])
+    assert_equal("theAuthor", result['items'][0]['properties']['author'][0]['id'])
+
 # unicode tests
 
 def get_all_files():
@@ -905,4 +921,14 @@ def test_input_tree_integrity():
 def make_labelled_cmp(label):
     f = lambda html1, html2: assert_equal(html1,html2)
     f.description = label
-    return f
\ No newline at end of file
+    return f
+
+def test_all_u_cases():
+    """ test variations of u- parsing and that relative urls are always resolved """
+
+    URL_COUNT = 28
+    result = parse_fixture("u_all_cases.html")
+
+    assert_equal(URL_COUNT, len(result['items'][0]['properties']['url']))
+    for i in range(URL_COUNT):
+        yield make_labelled_cmp("all_u_cases_" + str(i)), "http://example.com/test", result['items'][0]['properties']['url'][i]
